Readable

Trait Readable 

pub trait Readable: RegisterSpec {
    type Reader: From<R<Self>> + Deref<Target = R<Self>>;
}
Trait implemented by readable registers to enable the read method.

Registers marked with Writable can be also modify’ed.

Required Associated Types

type Reader: From<R<Self>> + Deref<Target = R<Self>>

Result from a call to read and argument to modify.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Readable for AFE_CTRL_SPEC

read() method returns afe_ctrl::R reader structure

Source

impl Readable for ALI_ACK0_SPEC

read() method returns ali_ack0::R reader structure

Source

impl Readable for ALI_ACK1_SPEC

read() method returns ali_ack1::R reader structure

Source

impl Readable for ALI_CONNECT0_SPEC

read() method returns ali_connect0::R reader structure

Source

impl Readable for ALI_CONNECT1_SPEC

read() method returns ali_connect1::R reader structure

Source

impl Readable for ALI_REQ0_SPEC

read() method returns ali_req0::R reader structure

Source

impl Readable for ALI_REQ1_SPEC

read() method returns ali_req1::R reader structure

Source

impl Readable for BASE_PART_NUM_SPEC

read() method returns base_part_num::R reader structure

Source

impl Readable for BAUD_SPEC

read() method returns baud::R reader structure

Source

impl Readable for BB_SPEC

read() method returns bb::R reader structure

Source

impl Readable for BL_CTRL_SPEC

read() method returns bl_ctrl::R reader structure

Source

impl Readable for BUF_OVR_INT_SPEC

read() method returns buf_ovr_int::R reader structure

Source

impl Readable for BYPASS_SPEC

read() method returns bypass::R reader structure

Source

impl Readable for max3263x::pmu0::cfg::CFG_SPEC

read() method returns cfg::R reader structure

Source

impl Readable for max3263x::owm::cfg::CFG_SPEC

read() method returns cfg::R reader structure

Source

impl Readable for CLEAR_SPEC

read() method returns clear::R reader structure

Source

impl Readable for CLK_CONFIG_SPEC

read() method returns clk_config::R reader structure

Source

impl Readable for max3263x::clkman::clk_ctrl::CLK_CTRL_SPEC

read() method returns clk_ctrl::R reader structure

Source

impl Readable for max3263x::rtccfg::clk_ctrl::CLK_CTRL_SPEC

read() method returns clk_ctrl::R reader structure

Source

impl Readable for CLK_DIV_1US_SPEC

read() method returns clk_div_1us::R reader structure

Source

impl Readable for CLK_DIV_SPEC

read() method returns clk_div::R reader structure

Source

impl Readable for CLK_GATE_CTRL0_SPEC

read() method returns clk_gate_ctrl0::R reader structure

Source

impl Readable for CLK_GATE_CTRL1_SPEC

read() method returns clk_gate_ctrl1::R reader structure

Source

impl Readable for CLK_GATE_CTRL2_SPEC

read() method returns clk_gate_ctrl2::R reader structure

Source

impl Readable for CM4_START_CLK_EN0_SPEC

read() method returns cm4_start_clk_en0::R reader structure

Source

impl Readable for CM4_START_CLK_EN1_SPEC

read() method returns cm4_start_clk_en1::R reader structure

Source

impl Readable for CM4_START_CLK_EN2_SPEC

read() method returns cm4_start_clk_en2::R reader structure

Source

impl Readable for CN_SPEC

read() method returns cn::R reader structure

Source

impl Readable for COMP0_SPEC

read() method returns comp0::R reader structure

Source

impl Readable for COMP1_SPEC

read() method returns comp1::R reader structure

Source

impl Readable for COUNT16_0_SPEC

read() method returns count16_0::R reader structure

Source

impl Readable for COUNT16_1_SPEC

read() method returns count16_1::R reader structure

Source

impl Readable for COUNT32_SPEC

read() method returns count32::R reader structure

Source

impl Readable for CRYPT_CLK_CTRL_0_AES_SPEC

read() method returns crypt_clk_ctrl_0_aes::R reader structure

Source

impl Readable for CRYPT_CLK_CTRL_1_MAA_SPEC

read() method returns crypt_clk_ctrl_1_maa::R reader structure

Source

impl Readable for CRYPT_CLK_CTRL_2_PRNG_SPEC

read() method returns crypt_clk_ctrl_2_prng::R reader structure

Source

impl Readable for CTRL2_SPEC

read() method returns ctrl2::R reader structure

Source

impl Readable for max3263x::rtctmr::ctrl::CTRL_SPEC

read() method returns ctrl::R reader structure

Source

impl Readable for max3263x::flc::ctrl::CTRL_SPEC

read() method returns ctrl::R reader structure

Source

impl Readable for max3263x::aes::ctrl::CTRL_SPEC

read() method returns ctrl::R reader structure

Source

impl Readable for max3263x::maa::ctrl::CTRL_SPEC

read() method returns ctrl::R reader structure

Source

impl Readable for max3263x::wdt0::ctrl::CTRL_SPEC

read() method returns ctrl::R reader structure

Source

impl Readable for max3263x::tmr0::ctrl::CTRL_SPEC

read() method returns ctrl::R reader structure

Source

impl Readable for max3263x::uart0::ctrl::CTRL_SPEC

read() method returns ctrl::R reader structure

Source

impl Readable for max3263x::i2cm0::ctrl::CTRL_SPEC

read() method returns ctrl::R reader structure

Source

impl Readable for max3263x::adc::ctrl::CTRL_SPEC

read() method returns ctrl::R reader structure

Source

impl Readable for max3263x::icc::ctrl_stat::CTRL_STAT_SPEC

read() method returns ctrl_stat::R reader structure

Source

impl Readable for max3263x::owm::ctrl_stat::CTRL_STAT_SPEC

read() method returns ctrl_stat::R reader structure

Source

impl Readable for CUR_BUF_SPEC

read() method returns cur_buf::R reader structure

Source

impl Readable for DATA_BYTE_SPEC

read() method returns data_byte::R reader structure

Source

impl Readable for max3263x::owm::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for max3263x::adc::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for DEV_ADDR_SPEC

read() method returns dev_addr::R reader structure

Source

impl Readable for DEV_CN_SPEC

read() method returns dev_cn::R reader structure

Source

impl Readable for DEV_ID_SPEC

read() method returns dev_id::R reader structure

Source

impl Readable for DEV_INTEN_SPEC

read() method returns dev_inten::R reader structure

Source

impl Readable for DEV_INTFL_SPEC

read() method returns dev_intfl::R reader structure

Source

impl Readable for DIE_TYPE_SPEC

read() method returns die_type::R reader structure

Source

impl Readable for DISABLE_WE0_SPEC

read() method returns disable_we0::R reader structure

Source

impl Readable for DISABLE_WE1_SPEC

read() method returns disable_we1::R reader structure

Source

impl Readable for DISABLE_WE2_SPEC

read() method returns disable_we2::R reader structure

Source

impl Readable for DISABLE_WE3_SPEC

read() method returns disable_we3::R reader structure

Source

impl Readable for DISABLE_WE4_SPEC

read() method returns disable_we4::R reader structure

Source

impl Readable for DISABLE_WE5_SPEC

read() method returns disable_we5::R reader structure

Source

impl Readable for DISABLE_WE6_SPEC

read() method returns disable_we6::R reader structure

Source

impl Readable for DISABLE_WE7_SPEC

read() method returns disable_we7::R reader structure

Source

impl Readable for DISABLE_XR0_SPEC

read() method returns disable_xr0::R reader structure

Source

impl Readable for DISABLE_XR1_SPEC

read() method returns disable_xr1::R reader structure

Source

impl Readable for DISABLE_XR2_SPEC

read() method returns disable_xr2::R reader structure

Source

impl Readable for DISABLE_XR3_SPEC

read() method returns disable_xr3::R reader structure

Source

impl Readable for DISABLE_XR4_SPEC

read() method returns disable_xr4::R reader structure

Source

impl Readable for DISABLE_XR5_SPEC

read() method returns disable_xr5::R reader structure

Source

impl Readable for DISABLE_XR6_SPEC

read() method returns disable_xr6::R reader structure

Source

impl Readable for DISABLE_XR7_SPEC

read() method returns disable_xr7::R reader structure

Source

impl Readable for DMA_ERR_INT_SPEC

read() method returns dma_err_int::R reader structure

Source

impl Readable for DSC1_SPEC

read() method returns dsc1::R reader structure

Source

impl Readable for DSC2_SPEC

read() method returns dsc2::R reader structure

Source

impl Readable for DSC3_SPEC

read() method returns dsc3::R reader structure

Source

impl Readable for DSC4_SPEC

read() method returns dsc4::R reader structure

Source

impl Readable for DSCADR_SPEC

read() method returns dscadr::R reader structure

Source

impl Readable for max3263x::wdt0::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for max3263x::ptg::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for EP0_SPEC

read() method returns ep0::R reader structure

Source

impl Readable for EP1_SPEC

read() method returns ep1::R reader structure

Source

impl Readable for EP2_SPEC

read() method returns ep2::R reader structure

Source

impl Readable for EP3_SPEC

read() method returns ep3::R reader structure

Source

impl Readable for EP4_SPEC

read() method returns ep4::R reader structure

Source

impl Readable for EP5_SPEC

read() method returns ep5::R reader structure

Source

impl Readable for EP6_SPEC

read() method returns ep6::R reader structure

Source

impl Readable for EP7_SPEC

read() method returns ep7::R reader structure

Source

impl Readable for EP_BASE_SPEC

read() method returns ep_base::R reader structure

Source

impl Readable for FADDR_SPEC

read() method returns faddr::R reader structure

Source

impl Readable for FCKDIV_SPEC

read() method returns fckdiv::R reader structure

Source

impl Readable for FDATA_SPEC

read() method returns fdata::R reader structure

Source

impl Readable for FETCH_CTRL_SPEC

read() method returns fetch_ctrl::R reader structure

Source

impl Readable for max3263x::spim0::fifo_ctrl::FIFO_CTRL_SPEC

read() method returns fifo_ctrl::R reader structure

Source

impl Readable for max3263x::spis::fifo_ctrl::FIFO_CTRL_SPEC

read() method returns fifo_ctrl::R reader structure

Source

impl Readable for FIFO_STAT_SPEC

read() method returns fifo_stat::R reader structure

Source

impl Readable for max3263x::rtctmr::flags::FLAGS_SPEC

read() method returns flags::R reader structure

Source

impl Readable for max3263x::pwrseq::flags::FLAGS_SPEC

read() method returns flags::R reader structure

Source

impl Readable for max3263x::wdt0::flags::FLAGS_SPEC

read() method returns flags::R reader structure

Source

impl Readable for FREE_P0_SPEC

read() method returns free_p0::R reader structure

Source

impl Readable for FREE_P1_SPEC

read() method returns free_p1::R reader structure

Source

impl Readable for FREE_P2_SPEC

read() method returns free_p2::R reader structure

Source

impl Readable for FREE_P3_SPEC

read() method returns free_p3::R reader structure

Source

impl Readable for FREE_P4_SPEC

read() method returns free_p4::R reader structure

Source

impl Readable for FREE_P5_SPEC

read() method returns free_p5::R reader structure

Source

impl Readable for FREE_P6_SPEC

read() method returns free_p6::R reader structure

Source

impl Readable for FREE_P7_SPEC

read() method returns free_p7::R reader structure

Source

impl Readable for FREE_P8_SPEC

read() method returns free_p8::R reader structure

Source

impl Readable for FS_CLK_DIV_SPEC

read() method returns fs_clk_div::R reader structure

Source

impl Readable for FUNC_SEL_P0_SPEC

read() method returns func_sel_p0::R reader structure

Source

impl Readable for FUNC_SEL_P1_SPEC

read() method returns func_sel_p1::R reader structure

Source

impl Readable for FUNC_SEL_P2_SPEC

read() method returns func_sel_p2::R reader structure

Source

impl Readable for FUNC_SEL_P3_SPEC

read() method returns func_sel_p3::R reader structure

Source

impl Readable for FUNC_SEL_P4_SPEC

read() method returns func_sel_p4::R reader structure

Source

impl Readable for FUNC_SEL_P5_SPEC

read() method returns func_sel_p5::R reader structure

Source

impl Readable for FUNC_SEL_P6_SPEC

read() method returns func_sel_p6::R reader structure

Source

impl Readable for FUNC_SEL_P7_SPEC

read() method returns func_sel_p7::R reader structure

Source

impl Readable for FUNC_SEL_P8_SPEC

read() method returns func_sel_p8::R reader structure

Source

impl Readable for max3263x::spim0::gen_ctrl::GEN_CTRL_SPEC

read() method returns gen_ctrl::R reader structure

Source

impl Readable for max3263x::spis::gen_ctrl::GEN_CTRL_SPEC

read() method returns gen_ctrl::R reader structure

Source

impl Readable for I2CM0_ACK_SPEC

read() method returns i2cm0_ack::R reader structure

Source

impl Readable for I2CM0_REQ_SPEC

read() method returns i2cm0_req::R reader structure

Source

impl Readable for I2CM1_ACK_SPEC

read() method returns i2cm1_ack::R reader structure

Source

impl Readable for I2CM1_REQ_SPEC

read() method returns i2cm1_req::R reader structure

Source

impl Readable for I2CM2_ACK_SPEC

read() method returns i2cm2_ack::R reader structure

Source

impl Readable for I2CM2_REQ_SPEC

read() method returns i2cm2_req::R reader structure

Source

impl Readable for I2CS_ACK_SPEC

read() method returns i2cs_ack::R reader structure

Source

impl Readable for I2CS_REQ_SPEC

read() method returns i2cs_req::R reader structure

Source

impl Readable for I2C_TIMER_CTRL_SPEC

read() method returns i2c_timer_ctrl::R reader structure

Source

impl Readable for ID_SPEC

read() method returns id::R reader structure

Source

impl Readable for INTEN1_SPEC

read() method returns inten1::R reader structure

Source

impl Readable for INTEN_P0_SPEC

read() method returns inten_p0::R reader structure

Source

impl Readable for INTEN_P1_SPEC

read() method returns inten_p1::R reader structure

Source

impl Readable for INTEN_P2_SPEC

read() method returns inten_p2::R reader structure

Source

impl Readable for INTEN_P3_SPEC

read() method returns inten_p3::R reader structure

Source

impl Readable for INTEN_P4_SPEC

read() method returns inten_p4::R reader structure

Source

impl Readable for INTEN_P5_SPEC

read() method returns inten_p5::R reader structure

Source

impl Readable for INTEN_P6_SPEC

read() method returns inten_p6::R reader structure

Source

impl Readable for INTEN_P7_SPEC

read() method returns inten_p7::R reader structure

Source

impl Readable for INTEN_P8_SPEC

read() method returns inten_p8::R reader structure

Source

impl Readable for max3263x::clkman::inten::INTEN_SPEC

read() method returns inten::R reader structure

Source

impl Readable for max3263x::pwrman::inten::INTEN_SPEC

read() method returns inten::R reader structure

Source

impl Readable for max3263x::rtctmr::inten::INTEN_SPEC

read() method returns inten::R reader structure

Source

impl Readable for max3263x::tmr0::inten::INTEN_SPEC

read() method returns inten::R reader structure

Source

impl Readable for max3263x::uart0::inten::INTEN_SPEC

read() method returns inten::R reader structure

Source

impl Readable for max3263x::ptg::inten::INTEN_SPEC

read() method returns inten::R reader structure

Source

impl Readable for max3263x::i2cm0::inten::INTEN_SPEC

read() method returns inten::R reader structure

Source

impl Readable for max3263x::i2cs::inten::INTEN_SPEC

read() method returns inten::R reader structure

Source

impl Readable for max3263x::spim0::inten::INTEN_SPEC

read() method returns inten::R reader structure

Source

impl Readable for max3263x::owm::inten::INTEN_SPEC

read() method returns inten::R reader structure

Source

impl Readable for max3263x::spis::inten::INTEN_SPEC

read() method returns inten::R reader structure

Source

impl Readable for INTFL1_SPEC

read() method returns intfl1::R reader structure

Source

impl Readable for INTFL_P0_SPEC

read() method returns intfl_p0::R reader structure

Source

impl Readable for INTFL_P1_SPEC

read() method returns intfl_p1::R reader structure

Source

impl Readable for INTFL_P2_SPEC

read() method returns intfl_p2::R reader structure

Source

impl Readable for INTFL_P3_SPEC

read() method returns intfl_p3::R reader structure

Source

impl Readable for INTFL_P4_SPEC

read() method returns intfl_p4::R reader structure

Source

impl Readable for INTFL_P5_SPEC

read() method returns intfl_p5::R reader structure

Source

impl Readable for INTFL_P6_SPEC

read() method returns intfl_p6::R reader structure

Source

impl Readable for INTFL_P7_SPEC

read() method returns intfl_p7::R reader structure

Source

impl Readable for INTFL_P8_SPEC

read() method returns intfl_p8::R reader structure

Source

impl Readable for max3263x::clkman::intfl::INTFL_SPEC

read() method returns intfl::R reader structure

Source

impl Readable for max3263x::pwrman::intfl::INTFL_SPEC

read() method returns intfl::R reader structure

Source

impl Readable for max3263x::tmr0::intfl::INTFL_SPEC

read() method returns intfl::R reader structure

Source

impl Readable for max3263x::uart0::intfl::INTFL_SPEC

read() method returns intfl::R reader structure

Source

impl Readable for max3263x::ptg::intfl::INTFL_SPEC

read() method returns intfl::R reader structure

Source

impl Readable for max3263x::i2cm0::intfl::INTFL_SPEC

read() method returns intfl::R reader structure

Source

impl Readable for max3263x::i2cs::intfl::INTFL_SPEC

read() method returns intfl::R reader structure

Source

impl Readable for max3263x::spim0::intfl::INTFL_SPEC

read() method returns intfl::R reader structure

Source

impl Readable for max3263x::owm::intfl::INTFL_SPEC

read() method returns intfl::R reader structure

Source

impl Readable for max3263x::spis::intfl::INTFL_SPEC

read() method returns intfl::R reader structure

Source

impl Readable for max3263x::flc::intr::INTR_SPEC

read() method returns intr::R reader structure

Source

impl Readable for max3263x::adc::intr::INTR_SPEC

read() method returns intr::R reader structure

Source

impl Readable for INT_MODE_P0_SPEC

read() method returns int_mode_p0::R reader structure

Source

impl Readable for INT_MODE_P1_SPEC

read() method returns int_mode_p1::R reader structure

Source

impl Readable for INT_MODE_P2_SPEC

read() method returns int_mode_p2::R reader structure

Source

impl Readable for INT_MODE_P3_SPEC

read() method returns int_mode_p3::R reader structure

Source

impl Readable for INT_MODE_P4_SPEC

read() method returns int_mode_p4::R reader structure

Source

impl Readable for INT_MODE_P5_SPEC

read() method returns int_mode_p5::R reader structure

Source

impl Readable for INT_MODE_P6_SPEC

read() method returns int_mode_p6::R reader structure

Source

impl Readable for INT_MODE_P7_SPEC

read() method returns int_mode_p7::R reader structure

Source

impl Readable for INT_MODE_P8_SPEC

read() method returns int_mode_p8::R reader structure

Source

impl Readable for INVDT_ALL_SPEC

read() method returns invdt_all::R reader structure

Source

impl Readable for IN_INT_SPEC

read() method returns in_int::R reader structure

Source

impl Readable for IN_MODE_P0_SPEC

read() method returns in_mode_p0::R reader structure

Source

impl Readable for IN_MODE_P1_SPEC

read() method returns in_mode_p1::R reader structure

Source

impl Readable for IN_MODE_P2_SPEC

read() method returns in_mode_p2::R reader structure

Source

impl Readable for IN_MODE_P3_SPEC

read() method returns in_mode_p3::R reader structure

Source

impl Readable for IN_MODE_P4_SPEC

read() method returns in_mode_p4::R reader structure

Source

impl Readable for IN_MODE_P5_SPEC

read() method returns in_mode_p5::R reader structure

Source

impl Readable for IN_MODE_P6_SPEC

read() method returns in_mode_p6::R reader structure

Source

impl Readable for IN_MODE_P7_SPEC

read() method returns in_mode_p7::R reader structure

Source

impl Readable for IN_MODE_P8_SPEC

read() method returns in_mode_p8::R reader structure

Source

impl Readable for IN_OWNER_SPEC

read() method returns in_owner::R reader structure

Source

impl Readable for IN_VAL_P0_SPEC

read() method returns in_val_p0::R reader structure

Source

impl Readable for IN_VAL_P1_SPEC

read() method returns in_val_p1::R reader structure

Source

impl Readable for IN_VAL_P2_SPEC

read() method returns in_val_p2::R reader structure

Source

impl Readable for IN_VAL_P3_SPEC

read() method returns in_val_p3::R reader structure

Source

impl Readable for IN_VAL_P4_SPEC

read() method returns in_val_p4::R reader structure

Source

impl Readable for IN_VAL_P5_SPEC

read() method returns in_val_p5::R reader structure

Source

impl Readable for IN_VAL_P6_SPEC

read() method returns in_val_p6::R reader structure

Source

impl Readable for IN_VAL_P7_SPEC

read() method returns in_val_p7::R reader structure

Source

impl Readable for IN_VAL_P8_SPEC

read() method returns in_val_p8::R reader structure

Source

impl Readable for LIMIT0_SPEC

read() method returns limit0::R reader structure

Source

impl Readable for LIMIT1_SPEC

read() method returns limit1::R reader structure

Source

impl Readable for LIMIT2_SPEC

read() method returns limit2::R reader structure

Source

impl Readable for LIMIT3_SPEC

read() method returns limit3::R reader structure

Source

impl Readable for LOCK_CTRL_SPEC

read() method returns lock_ctrl::R reader structure

Source

impl Readable for max3263x::pmu0::loop_::LOOP_SPEC

read() method returns loop_::R reader structure

Source

impl Readable for max3263x::pt0::loop_::LOOP_SPEC

read() method returns loop_::R reader structure

Source

impl Readable for MARGIN_CTRL_SPEC

read() method returns margin_ctrl::R reader structure

Source

impl Readable for MASK_ID0_SPEC

read() method returns mask_id0::R reader structure

Source

impl Readable for MASK_ID1_SPEC

read() method returns mask_id1::R reader structure

Source

impl Readable for MASTER_CFG_SPEC

read() method returns master_cfg::R reader structure

Source

impl Readable for MAWS_SPEC

read() method returns maws::R reader structure

Source

impl Readable for MD_CTRL_SPEC

read() method returns md_ctrl::R reader structure

Source

impl Readable for MEM_CFG_SPEC

read() method returns mem_cfg::R reader structure

Source

impl Readable for MODE_CTRL_SPEC

read() method returns mode_ctrl::R reader structure

Source

impl Readable for MODE_DATA_SPEC

read() method returns mode_data::R reader structure

Source

impl Readable for MSK_FLAGS_SPEC

read() method returns msk_flags::R reader structure

Source

impl Readable for MSTR_CFG_SPEC

read() method returns mstr_cfg::R reader structure

Source

impl Readable for NAK_INT_SPEC

read() method returns nak_int::R reader structure

Source

impl Readable for NANO_CNTR_SPEC

read() method returns nano_cntr::R reader structure

Source

impl Readable for OP_SPEC

read() method returns op::R reader structure

Source

impl Readable for OSC_CTRL_SPEC

read() method returns osc_ctrl::R reader structure

Source

impl Readable for OUT_INT_SPEC

read() method returns out_int::R reader structure

Source

impl Readable for OUT_MODE_P0_SPEC

read() method returns out_mode_p0::R reader structure

Source

impl Readable for OUT_MODE_P1_SPEC

read() method returns out_mode_p1::R reader structure

Source

impl Readable for OUT_MODE_P2_SPEC

read() method returns out_mode_p2::R reader structure

Source

impl Readable for OUT_MODE_P3_SPEC

read() method returns out_mode_p3::R reader structure

Source

impl Readable for OUT_MODE_P4_SPEC

read() method returns out_mode_p4::R reader structure

Source

impl Readable for OUT_MODE_P5_SPEC

read() method returns out_mode_p5::R reader structure

Source

impl Readable for OUT_MODE_P6_SPEC

read() method returns out_mode_p6::R reader structure

Source

impl Readable for OUT_MODE_P7_SPEC

read() method returns out_mode_p7::R reader structure

Source

impl Readable for OUT_MODE_P8_SPEC

read() method returns out_mode_p8::R reader structure

Source

impl Readable for OUT_OWNER_SPEC

read() method returns out_owner::R reader structure

Source

impl Readable for OUT_VAL_P0_SPEC

read() method returns out_val_p0::R reader structure

Source

impl Readable for OUT_VAL_P1_SPEC

read() method returns out_val_p1::R reader structure

Source

impl Readable for OUT_VAL_P2_SPEC

read() method returns out_val_p2::R reader structure

Source

impl Readable for OUT_VAL_P3_SPEC

read() method returns out_val_p3::R reader structure

Source

impl Readable for OUT_VAL_P4_SPEC

read() method returns out_val_p4::R reader structure

Source

impl Readable for OUT_VAL_P5_SPEC

read() method returns out_val_p5::R reader structure

Source

impl Readable for OUT_VAL_P6_SPEC

read() method returns out_val_p6::R reader structure

Source

impl Readable for OUT_VAL_P7_SPEC

read() method returns out_val_p7::R reader structure

Source

impl Readable for OUT_VAL_P8_SPEC

read() method returns out_val_p8::R reader structure

Source

impl Readable for OWM_ACK_SPEC

read() method returns owm_ack::R reader structure

Source

impl Readable for OWM_REQ_SPEC

read() method returns owm_req::R reader structure

Source

impl Readable for PDM33_SPEC

read() method returns pdm33::R reader structure

Source

impl Readable for PERFORM_SPEC

read() method returns perform::R reader structure

Source

impl Readable for PERIPHERAL_RESET_SPEC

read() method returns peripheral_reset::R reader structure

Source

impl Readable for PRESCALE_MASK_SPEC

read() method returns prescale_mask::R reader structure

Source

impl Readable for PRESCALE_SPEC

read() method returns prescale::R reader structure

Source

impl Readable for PRNG_RND_NUM_SPEC

read() method returns prng_rnd_num::R reader structure

Source

impl Readable for PRNG_USER_ENTROPY_SPEC

read() method returns prng_user_entropy::R reader structure

Source

impl Readable for PWM_CAP32_SPEC

read() method returns pwm_cap32::R reader structure

Source

impl Readable for PWR_RST_CTRL_SPEC

read() method returns pwr_rst_ctrl::R reader structure

Source

impl Readable for RATE_LENGTH_SPEC

read() method returns rate_length::R reader structure

Source

impl Readable for REG0_SPEC

read() method returns reg0::R reader structure

Source

impl Readable for REG1_SPEC

read() method returns reg1::R reader structure

Source

impl Readable for REG2_SPEC

read() method returns reg2::R reader structure

Source

impl Readable for REG3_SPEC

read() method returns reg3::R reader structure

Source

impl Readable for REG4_SPEC

read() method returns reg4::R reader structure

Source

impl Readable for REG5_SPEC

read() method returns reg5::R reader structure

Source

impl Readable for REG6_SPEC

read() method returns reg6::R reader structure

Source

impl Readable for REG7_SPEC

read() method returns reg7::R reader structure

Source

impl Readable for RESEED_SPEC

read() method returns reseed::R reader structure

Source

impl Readable for RESYNC_SPEC

read() method returns resync::R reader structure

Source

impl Readable for RO_CAL0_SPEC

read() method returns ro_cal0::R reader structure

Source

impl Readable for RO_CAL1_SPEC

read() method returns ro_cal1::R reader structure

Source

impl Readable for RO_CAL2_SPEC

read() method returns ro_cal2::R reader structure

Source

impl Readable for RST_MODE_P0_SPEC

read() method returns rst_mode_p0::R reader structure

Source

impl Readable for RST_MODE_P1_SPEC

read() method returns rst_mode_p1::R reader structure

Source

impl Readable for RST_MODE_P2_SPEC

read() method returns rst_mode_p2::R reader structure

Source

impl Readable for RST_MODE_P3_SPEC

read() method returns rst_mode_p3::R reader structure

Source

impl Readable for RST_MODE_P4_SPEC

read() method returns rst_mode_p4::R reader structure

Source

impl Readable for RST_MODE_P5_SPEC

read() method returns rst_mode_p5::R reader structure

Source

impl Readable for RST_MODE_P6_SPEC

read() method returns rst_mode_p6::R reader structure

Source

impl Readable for RST_MODE_P7_SPEC

read() method returns rst_mode_p7::R reader structure

Source

impl Readable for RST_MODE_P8_SPEC

read() method returns rst_mode_p8::R reader structure

Source

impl Readable for RX_FIFO_CTRL_SPEC

read() method returns rx_fifo_ctrl::R reader structure

Source

impl Readable for SECURITY_SPEC

read() method returns security::R reader structure

Source

impl Readable for SEED16_SPEC

read() method returns seed16::R reader structure

Source

impl Readable for SEED32_SPEC

read() method returns seed32::R reader structure

Source

impl Readable for SETUP0_SPEC

read() method returns setup0::R reader structure

Source

impl Readable for SETUP1_SPEC

read() method returns setup1::R reader structure

Source

impl Readable for SKS0_SPEC

read() method returns sks0::R reader structure

Source

impl Readable for SKS1_SPEC

read() method returns sks1::R reader structure

Source

impl Readable for SKS2_SPEC

read() method returns sks2::R reader structure

Source

impl Readable for SKS3_SPEC

read() method returns sks3::R reader structure

Source

impl Readable for SLM_SPEC

read() method returns slm::R reader structure

Source

impl Readable for SNZ_VALUE_SPEC

read() method returns snz_value::R reader structure

Source

impl Readable for SPCL_CTRL_SPEC

read() method returns spcl_ctrl::R reader structure

Source

impl Readable for SPI0_ACK_SPEC

read() method returns spi0_ack::R reader structure

Source

impl Readable for SPI0_REQ_SPEC

read() method returns spi0_req::R reader structure

Source

impl Readable for SPI1_ACK_SPEC

read() method returns spi1_ack::R reader structure

Source

impl Readable for SPI1_REQ_SPEC

read() method returns spi1_req::R reader structure

Source

impl Readable for SPI2_ACK_SPEC

read() method returns spi2_ack::R reader structure

Source

impl Readable for SPI2_REQ_SPEC

read() method returns spi2_req::R reader structure

Source

impl Readable for SPIB_ACK_SPEC

read() method returns spib_ack::R reader structure

Source

impl Readable for SPIB_REQ_SPEC

read() method returns spib_req::R reader structure

Source

impl Readable for SPIX_ACK_SPEC

read() method returns spix_ack::R reader structure

Source

impl Readable for SPIX_REQ_SPEC

read() method returns spix_req::R reader structure

Source

impl Readable for SS_SR_POLARITY_SPEC

read() method returns ss_sr_polarity::R reader structure

Source

impl Readable for max3263x::flc::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for max3263x::adc::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for SVM_EVENTS_SPEC

read() method returns svm_events::R reader structure

Source

impl Readable for SYS_CLK_CTRL_0_CM4_SPEC

read() method returns sys_clk_ctrl_0_cm4::R reader structure

Source

impl Readable for SYS_CLK_CTRL_1_SYNC_SPEC

read() method returns sys_clk_ctrl_1_sync::R reader structure

Source

impl Readable for SYS_CLK_CTRL_2_SPIX_SPEC

read() method returns sys_clk_ctrl_2_spix::R reader structure

Source

impl Readable for SYS_CLK_CTRL_3_PRNG_SPEC

read() method returns sys_clk_ctrl_3_prng::R reader structure

Source

impl Readable for SYS_CLK_CTRL_4_WDT0_SPEC

read() method returns sys_clk_ctrl_4_wdt0::R reader structure

Source

impl Readable for SYS_CLK_CTRL_5_WDT1_SPEC

read() method returns sys_clk_ctrl_5_wdt1::R reader structure

Source

impl Readable for SYS_CLK_CTRL_6_GPIO_SPEC

read() method returns sys_clk_ctrl_6_gpio::R reader structure

Source

impl Readable for SYS_CLK_CTRL_7_PT_SPEC

read() method returns sys_clk_ctrl_7_pt::R reader structure

Source

impl Readable for SYS_CLK_CTRL_8_UART_SPEC

read() method returns sys_clk_ctrl_8_uart::R reader structure

Source

impl Readable for SYS_CLK_CTRL_9_I2CM_SPEC

read() method returns sys_clk_ctrl_9_i2cm::R reader structure

Source

impl Readable for SYS_CLK_CTRL_10_I2CS_SPEC

read() method returns sys_clk_ctrl_10_i2cs::R reader structure

Source

impl Readable for SYS_CLK_CTRL_11_SPI0_SPEC

read() method returns sys_clk_ctrl_11_spi0::R reader structure

Source

impl Readable for SYS_CLK_CTRL_12_SPI1_SPEC

read() method returns sys_clk_ctrl_12_spi1::R reader structure

Source

impl Readable for SYS_CLK_CTRL_13_SPI2_SPEC

read() method returns sys_clk_ctrl_13_spi2::R reader structure

Source

impl Readable for SYS_CLK_CTRL_14_SPIB_SPEC

read() method returns sys_clk_ctrl_14_spib::R reader structure

Source

impl Readable for SYS_CLK_CTRL_15_OWM_SPEC

read() method returns sys_clk_ctrl_15_owm::R reader structure

Source

impl Readable for SYS_CLK_CTRL_16_SPIS_SPEC

read() method returns sys_clk_ctrl_16_spis::R reader structure

Source

impl Readable for TACC_SPEC

read() method returns tacc::R reader structure

Source

impl Readable for TERM_CNT16_0_SPEC

read() method returns term_cnt16_0::R reader structure

Source

impl Readable for TERM_CNT16_1_SPEC

read() method returns term_cnt16_1::R reader structure

Source

impl Readable for TERM_CNT32_SPEC

read() method returns term_cnt32::R reader structure

Source

impl Readable for TIMEOUT_SPEC

read() method returns timeout::R reader structure

Source

impl Readable for TIMER_SPEC

read() method returns timer::R reader structure

Source

impl Readable for TPROG_SPEC

read() method returns tprog::R reader structure

Source

impl Readable for TRAIN_SPEC

read() method returns train::R reader structure

Source

impl Readable for TRANS_SPEC

read() method returns trans::R reader structure

Source

impl Readable for TRIM_CALC_SPEC

read() method returns trim_calc::R reader structure

Source

impl Readable for TRIM_CTRL_SPEC

read() method returns trim_ctrl::R reader structure

Source

impl Readable for TRIM_VALUE_SPEC

read() method returns trim_value::R reader structure

Source

impl Readable for TWK_CYCL_CNT_SPEC

read() method returns twk_cycl_cnt::R reader structure

Source

impl Readable for TX_FIFO_CTRL_SPEC

read() method returns tx_fifo_ctrl::R reader structure

Source

impl Readable for UART0_ACK_SPEC

read() method returns uart0_ack::R reader structure

Source

impl Readable for UART0_REQ_SPEC

read() method returns uart0_req::R reader structure

Source

impl Readable for UART1_ACK_SPEC

read() method returns uart1_ack::R reader structure

Source

impl Readable for UART1_REQ_SPEC

read() method returns uart1_req::R reader structure

Source

impl Readable for UART2_ACK_SPEC

read() method returns uart2_ack::R reader structure

Source

impl Readable for UART2_REQ_SPEC

read() method returns uart2_req::R reader structure

Source

impl Readable for UART3_ACK_SPEC

read() method returns uart3_ack::R reader structure

Source

impl Readable for UART3_REQ_SPEC

read() method returns uart3_req::R reader structure

Source

impl Readable for USER_OPTION_SPEC

read() method returns user_option::R reader structure

Source

impl Readable for WUD_ACK0_SPEC

read() method returns wud_ack0::R reader structure

Source

impl Readable for WUD_ACK1_SPEC

read() method returns wud_ack1::R reader structure

Source

impl Readable for WUD_CTRL_SPEC

read() method returns wud_ctrl::R reader structure

Source

impl Readable for WUD_PULSE0_SPEC

read() method returns wud_pulse0::R reader structure

Source

impl Readable for WUD_PULSE1_SPEC

read() method returns wud_pulse1::R reader structure

Source

impl Readable for WUD_REQ0_SPEC

read() method returns wud_req0::R reader structure

Source

impl Readable for WUD_REQ1_SPEC

read() method returns wud_req1::R reader structure

Source

impl Readable for WUD_SEEN0_SPEC

read() method returns wud_seen0::R reader structure

Source

impl Readable for WUD_SEEN1_SPEC

read() method returns wud_seen1::R reader structure